@@ -4,6 +4,6 @@
 #include <stdlib.h>
 #include <stdint.h>
 
-size_t gbconv8(const char *src, char *dst, size_t dstlen);
+size_t gbconv8(const char *src, size_t srclen, char *dst, size_t dstlen);
 
 #endif
